import { jsxs, jsx } from "react/jsx-runtime";
import { memo, useState, useEffect } from "react";
import { Routes, Route } from "react-router-dom";
import { useFetchClient, Page, Layouts } from "@strapi/strapi/admin";
import { Box, Alert, Table, Thead, Tr, Th, Checkbox, Tbody, Td, Button } from "@strapi/design-system";
import { useIntl } from "react-intl";
import styled from "styled-components";
import { p as pluginId } from "./index-Gw3B3PjO.mjs";
const getTrad = (id) => `${pluginId}.${id}`;
const ButtonWrapper = styled.div`
  margin: 10px 0 0 0;

  & button {
    margin: 0 0 0 auto;
  }
`;
const Description = styled.p`
  font-size: 16px;
  margin: 20px 0;
`;
const AlertMessage = styled.div`
  margin-left: -250px;
  position: fixed;
  left: 50%;
  top: 2.875rem;
  z-index: 10;
  width: 31.25rem;
`;
const HomePage = () => {
  const { formatMessage } = useIntl();
  const [ssoRoles, setSSORoles] = useState([]);
  const [roles, setRoles] = useState([]);
  const [showSuccess, setSuccess] = useState(false);
  const [showError, setError] = useState(false);
  const { get, put } = useFetchClient();
  useEffect(() => {
    const init = async () => {
      const ssoRoleResponse = await get(`/lark-sso/sso-roles`);
      setSSORoles(ssoRoleResponse.data);
      const roleResponse = await get(`/admin/roles`);
      setRoles(roleResponse.data.data);
    };
    init();
  }, [setSSORoles, setRoles]);
  const onChangeCheck = (value, ssoId, role) => {
    for (const ssoRole of ssoRoles) {
      if (ssoRole["oauth_type"] === ssoId) {
        if (ssoRole["role"]) {
          if (value) {
            ssoRole["role"].push(role);
          } else {
            ssoRole["role"] = ssoRole["role"].filter((selectRole) => selectRole !== role);
          }
        } else {
          ssoRole["role"] = [role];
        }
      }
    }
    setSSORoles(ssoRoles.slice());
  };
  const onClickSave = async () => {
    try {
      await put("/lark-sso/sso-roles", {
        roles: ssoRoles.map((role) => ({
          "oauth_type": role["oauth_type"],
          role: role["role"]
        }))
      });
      setSuccess(true);
      setTimeout(() => {
        setSuccess(false);
      }, 3e3);
    } catch (e) {
      console.error(e);
      setError(true);
      setTimeout(() => {
        setError(false);
      }, 3e3);
    }
  };
  return /* @__PURE__ */ jsxs(Page.Protect, { permissions: [{ action: "plugin::lark-sso.read", subject: null }], children: [
    /* @__PURE__ */ jsx(
      Layouts.Header,
      {
        title: "Single Sign On",
        subtitle: formatMessage({
          id: getTrad("page.title"),
          defaultMessage: "Default role setting at first login"
        })
      }
    ),
    /* @__PURE__ */ jsxs(Box, { padding: 10, children: [
      showSuccess && /* @__PURE__ */ jsx(AlertMessage, { children: /* @__PURE__ */ jsx(
        Alert,
        {
          title: "Success",
          variant: "success",
          closeLabel: "",
          onClose: () => setSuccess(false),
          children: formatMessage({
            id: getTrad("page.save.success"),
            defaultMessage: "Updated settings"
          })
        }
      ) }),
      showError && /* @__PURE__ */ jsx(AlertMessage, { children: /* @__PURE__ */ jsx(
        Alert,
        {
          title: "Error",
          variant: "danger",
          closeLabel: "",
          onClose: () => setError(false),
          children: formatMessage({
            id: getTrad("page.save.error"),
            defaultMessage: "Update failed."
          })
        }
      ) }),
      /* @__PURE__ */ jsxs(Table, { colCount: roles.length + 1, rowCount: ssoRoles.length, children: [
        /* @__PURE__ */ jsx(Thead, { children: /* @__PURE__ */ jsxs(Tr, { children: [
          /* @__PURE__ */ jsx(Th, { children: /* @__PURE__ */ jsx(Checkbox, { style: { display: "none" } }) }),
          roles.map((role) => /* @__PURE__ */ jsx(Th, { children: role["name"] }, role["id"]))
        ] }) }),
        /* @__PURE__ */ jsx(Tbody, { children: ssoRoles.map((ssoRole) => /* @__PURE__ */ jsxs(Tr, { children: [
          /* @__PURE__ */ jsx(Td, { children: ssoRole["name"] }),
          roles.map((role) => /* @__PURE__ */ jsx(Th, { children: /* @__PURE__ */ jsx(
            Checkbox,
            {
              checked: ssoRole["role"] && ssoRole["role"].includes(role["id"]),
              onCheckedChange: (value) => {
                onChangeCheck(value, ssoRole["oauth_type"], role["id"]);
              },
              children: ""
            }
          ) }, role["id"]))
        ] }, ssoRole["oauth_type"])) })
      ] }),
      /* @__PURE__ */ jsx(Description, { children: formatMessage({
        id: getTrad("page.notes"),
        defaultMessage: "This will not be reflected for already registered users."
      }) }),
      /* @__PURE__ */ jsx(ButtonWrapper, { children: /* @__PURE__ */ jsx(Button, { variant: "default", onClick: onClickSave, children: formatMessage({
        id: getTrad("page.save"),
        defaultMessage: "Save"
      }) }) })
    ] })
  ] });
};
const HomePage$1 = memo(HomePage);
const App = () => {
  return /* @__PURE__ */ jsx("div", { children: /* @__PURE__ */ jsxs(Routes, { children: [
    /* @__PURE__ */ jsx(Route, { index: true, element: /* @__PURE__ */ jsx(HomePage$1, {}) }),
    /* @__PURE__ */ jsx(Route, { path: "*", element: /* @__PURE__ */ jsx(Page.Error, {}) })
  ] }) });
};
export {
  App as default
};
