"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const jsxRuntime = require("react/jsx-runtime");
const react = require("react");
const reactRouterDom = require("react-router-dom");
const admin = require("@strapi/strapi/admin");
const designSystem = require("@strapi/design-system");
const reactIntl = require("react-intl");
const styled = require("styled-components");
const index = require("./index-Bv-rwwRa.js");
const _interopDefault = (e) => e && e.__esModule ? e : { default: e };
const styled__default = /* @__PURE__ */ _interopDefault(styled);
const getTrad = (id) => `${index.pluginId}.${id}`;
const ButtonWrapper = styled__default.default.div`
  margin: 10px 0 0 0;

  & button {
    margin: 0 0 0 auto;
  }
`;
const Description = styled__default.default.p`
  font-size: 16px;
  margin: 20px 0;
`;
const AlertMessage = styled__default.default.div`
  margin-left: -250px;
  position: fixed;
  left: 50%;
  top: 2.875rem;
  z-index: 10;
  width: 31.25rem;
`;
const HomePage = () => {
  const { formatMessage } = reactIntl.useIntl();
  const [ssoRoles, setSSORoles] = react.useState([]);
  const [roles, setRoles] = react.useState([]);
  const [showSuccess, setSuccess] = react.useState(false);
  const [showError, setError] = react.useState(false);
  const { get, put } = admin.useFetchClient();
  react.useEffect(() => {
    const init = async () => {
      const ssoRoleResponse = await get(`/lark-sso/sso-roles`);
      setSSORoles(ssoRoleResponse.data);
      const roleResponse = await get(`/admin/roles`);
      setRoles(roleResponse.data.data);
    };
    init();
  }, [setSSORoles, setRoles]);
  const onChangeCheck = (value, ssoId, role) => {
    for (const ssoRole of ssoRoles) {
      if (ssoRole["oauth_type"] === ssoId) {
        if (ssoRole["role"]) {
          if (value) {
            ssoRole["role"].push(role);
          } else {
            ssoRole["role"] = ssoRole["role"].filter((selectRole) => selectRole !== role);
          }
        } else {
          ssoRole["role"] = [role];
        }
      }
    }
    setSSORoles(ssoRoles.slice());
  };
  const onClickSave = async () => {
    try {
      await put("/lark-sso/sso-roles", {
        roles: ssoRoles.map((role) => ({
          "oauth_type": role["oauth_type"],
          role: role["role"]
        }))
      });
      setSuccess(true);
      setTimeout(() => {
        setSuccess(false);
      }, 3e3);
    } catch (e) {
      console.error(e);
      setError(true);
      setTimeout(() => {
        setError(false);
      }, 3e3);
    }
  };
  return /* @__PURE__ */ jsxRuntime.jsxs(admin.Page.Protect, { permissions: [{ action: "plugin::lark-sso.read", subject: null }], children: [
    /* @__PURE__ */ jsxRuntime.jsx(
      admin.Layouts.Header,
      {
        title: "Single Sign On",
        subtitle: formatMessage({
          id: getTrad("page.title"),
          defaultMessage: "Default role setting at first login"
        })
      }
    ),
    /* @__PURE__ */ jsxRuntime.jsxs(designSystem.Box, { padding: 10, children: [
      showSuccess && /* @__PURE__ */ jsxRuntime.jsx(AlertMessage, { children: /* @__PURE__ */ jsxRuntime.jsx(
        designSystem.Alert,
        {
          title: "Success",
          variant: "success",
          closeLabel: "",
          onClose: () => setSuccess(false),
          children: formatMessage({
            id: getTrad("page.save.success"),
            defaultMessage: "Updated settings"
          })
        }
      ) }),
      showError && /* @__PURE__ */ jsxRuntime.jsx(AlertMessage, { children: /* @__PURE__ */ jsxRuntime.jsx(
        designSystem.Alert,
        {
          title: "Error",
          variant: "danger",
          closeLabel: "",
          onClose: () => setError(false),
          children: formatMessage({
            id: getTrad("page.save.error"),
            defaultMessage: "Update failed."
          })
        }
      ) }),
      /* @__PURE__ */ jsxRuntime.jsxs(designSystem.Table, { colCount: roles.length + 1, rowCount: ssoRoles.length, children: [
        /* @__PURE__ */ jsxRuntime.jsx(designSystem.Thead, { children: /* @__PURE__ */ jsxRuntime.jsxs(designSystem.Tr, { children: [
          /* @__PURE__ */ jsxRuntime.jsx(designSystem.Th, { children: /* @__PURE__ */ jsxRuntime.jsx(designSystem.Checkbox, { style: { display: "none" } }) }),
          roles.map((role) => /* @__PURE__ */ jsxRuntime.jsx(designSystem.Th, { children: role["name"] }, role["id"]))
        ] }) }),
        /* @__PURE__ */ jsxRuntime.jsx(designSystem.Tbody, { children: ssoRoles.map((ssoRole) => /* @__PURE__ */ jsxRuntime.jsxs(designSystem.Tr, { children: [
          /* @__PURE__ */ jsxRuntime.jsx(designSystem.Td, { children: ssoRole["name"] }),
          roles.map((role) => /* @__PURE__ */ jsxRuntime.jsx(designSystem.Th, { children: /* @__PURE__ */ jsxRuntime.jsx(
            designSystem.Checkbox,
            {
              checked: ssoRole["role"] && ssoRole["role"].includes(role["id"]),
              onCheckedChange: (value) => {
                onChangeCheck(value, ssoRole["oauth_type"], role["id"]);
              },
              children: ""
            }
          ) }, role["id"]))
        ] }, ssoRole["oauth_type"])) })
      ] }),
      /* @__PURE__ */ jsxRuntime.jsx(Description, { children: formatMessage({
        id: getTrad("page.notes"),
        defaultMessage: "This will not be reflected for already registered users."
      }) }),
      /* @__PURE__ */ jsxRuntime.jsx(ButtonWrapper, { children: /* @__PURE__ */ jsxRuntime.jsx(designSystem.Button, { variant: "default", onClick: onClickSave, children: formatMessage({
        id: getTrad("page.save"),
        defaultMessage: "Save"
      }) }) })
    ] })
  ] });
};
const HomePage$1 = react.memo(HomePage);
const App = () => {
  return /* @__PURE__ */ jsxRuntime.jsx("div", { children: /* @__PURE__ */ jsxRuntime.jsxs(reactRouterDom.Routes, { children: [
    /* @__PURE__ */ jsxRuntime.jsx(reactRouterDom.Route, { index: true, element: /* @__PURE__ */ jsxRuntime.jsx(HomePage$1, {}) }),
    /* @__PURE__ */ jsxRuntime.jsx(reactRouterDom.Route, { path: "*", element: /* @__PURE__ */ jsxRuntime.jsx(admin.Page.Error, {}) })
  ] }) });
};
exports.default = App;
