"use strict";
const axios = require("axios");
const crypto = require("crypto");
const strapiUtils = require("@strapi/utils");
const generator = require("generate-password");
const _interopDefault = (e) => e && e.__esModule ? e : { default: e };
const axios__default = /* @__PURE__ */ _interopDefault(axios);
const strapiUtils__default = /* @__PURE__ */ _interopDefault(strapiUtils);
const generator__default = /* @__PURE__ */ _interopDefault(generator);
const register = ({ strapi: strapi2 }) => {
};
const bootstrap = async ({ strapi: strapi2 }) => {
  const actions = [
    {
      section: "plugins",
      displayName: "Read",
      uid: "read",
      pluginName: "lark-sso"
    }
  ];
  await strapi2.admin.services.permission.actionProvider.registerMany(actions);
};
const destroy = ({ strapi: strapi2 }) => {
};
const config = {
  default: {
    REMEMBER_ME: false,
    LARK_OAUTH_REDIRECT_URI: "http://127.0.0.1:1337/lark-sso/lark/callback"
  },
  validator() {
  }
};
const info = {
  singularName: "roles",
  pluralName: "sso-roles",
  collectionName: "sso-roles",
  displayName: "sso-role",
  description: ""
};
const options = {
  draftAndPublish: false
};
const pluginOptions = {
  "content-manager": {
    visible: false
  },
  "content-type-builder": {
    visible: false
  }
};
const attributes = {
  oauth_type: {
    type: "string",
    configurable: false,
    required: true
  },
  roles: {
    type: "json",
    configurable: false
  }
};
const schema = {
  info,
  options,
  pluginOptions,
  attributes
};
const roles = {
  schema
};
const contentTypes = {
  roles
};
async function find(ctx) {
  const roleService = strapi.plugin("lark-sso").service("role");
  const roles2 = await roleService.find();
  const ssoConstants = roleService.ssoRoles();
  for (const sso of ssoConstants) {
    for (const role2 of roles2) {
      if (role2["oauth_type"] === sso["oauth_type"]) {
        sso["role"] = role2["roles"];
      }
    }
  }
  ctx.send(ssoConstants);
}
async function update(ctx) {
  try {
    const { roles: roles2 } = ctx.request.body;
    const roleService = strapi.plugin("lark-sso").service("role");
    await roleService.update(roles2);
    ctx.send({}, 204);
  } catch (e) {
    console.log(e);
    ctx.send({}, 400);
  }
}
const role$1 = {
  find,
  update
};
const configValidation = () => {
  const config2 = strapi.config.get("plugin::lark-sso");
  if (config2["LARK_APP_ID"] && config2["LARK_APP_SECRET"]) {
    return config2;
  }
  throw new Error("LARK_APP_ID and LARK_APP_SECRET are required");
};
async function larkSignIn(ctx) {
  const config2 = configValidation();
  const url = `${config2["OAUTH_ENDPOINT"]}?client_id=${config2["LARK_APP_ID"]}&response_type=code&scope=profile+email`;
  ctx.set("Location", url);
  return ctx.send({}, 302);
}
async function larkSignInCallback(ctx) {
  const config2 = configValidation();
  const httpClient = axios__default.default.create();
  const userService = strapi.service("admin::user");
  const tokenService = strapi.service("admin::token");
  const oauthService = strapi.plugin("lark-sso").service("oauth");
  const roleService = strapi.plugin("lark-sso").service("role");
  if (!ctx.query.code) {
    return ctx.send(oauthService.renderSignUpError(`code Not Found`));
  }
  try {
    const params = new URLSearchParams();
    params.append("code", ctx.query.code);
    params.append("client_id", config2["LARK_APP_ID"]);
    params.append("client_secret", config2["LARK_APP_SECRET"]);
    params.append("redirect_uri", config2["LARK_OAUTH_REDIRECT_URI"]);
    params.append("grant_type", "authorization_code");
    const tokenResponse = await httpClient.post(config2["OAUTH_TOKEN_ENDPOINT"], params, {
      headers: {
        "Content-Type": "application/x-www-form-urlencoded"
      }
    });
    console.log("tokenResponse", tokenResponse.data);
    const accessToken = tokenResponse.data.access_token;
    const userResponse = await httpClient.get(config2["OAUTH_USER_INFO_ENDPOINT"], {
      headers: {
        Authorization: `Bearer ${accessToken}`
      }
    });
    const email = userResponse.data.email;
    const dbUser = await userService.findOneByEmail(email);
    console.log("dbUser", dbUser);
    let activateUser;
    let jwtToken;
    if (dbUser) {
      activateUser = dbUser;
      jwtToken = await tokenService.createJwtToken(dbUser);
    } else {
      const defaultLocale = oauthService.localeFindByHeader(
        ctx.request.headers
      );
      const [familyName, givenName] = userResponse.data.name?.split(" ");
      const larkRoles = await roleService.larkRoles();
      const roles2 = larkRoles && larkRoles["roles"] ? larkRoles["roles"].map((role2) => ({
        id: role2
      })) : [];
      activateUser = await oauthService.createUser(
        email,
        familyName,
        givenName,
        defaultLocale,
        roles2
      );
      jwtToken = await tokenService.createJwtToken(activateUser);
      await oauthService.triggerWebHook(activateUser);
    }
    oauthService.triggerSignInSuccess(activateUser);
    const nonce = crypto.randomUUID();
    const html = oauthService.renderSignUpSuccess(
      jwtToken,
      activateUser,
      nonce
    );
    ctx.set("Content-Security-Policy", `script-src 'nonce-${nonce}'`);
    ctx.send(html);
  } catch (e) {
    console.error(e);
    ctx.send(oauthService.renderSignUpError(e.message));
  }
}
const lark = {
  larkSignIn,
  larkSignInCallback
};
const controllers = {
  role: role$1,
  lark
};
const routes = [
  {
    method: "GET",
    path: "/",
    handler: "lark.larkSignIn",
    config: {
      auth: false
    }
  },
  {
    method: "GET",
    path: "/callback",
    handler: "lark.larkSignInCallback",
    config: {
      auth: false
    }
  },
  {
    method: "GET",
    path: "/sso-roles",
    handler: "role.find"
  },
  {
    method: "PUT",
    path: "/sso-roles",
    handler: "role.update"
  }
];
const policies = {};
const oauth = ({ strapi: strapi2 }) => ({
  async createUser(email, lastname, firstname, locale, roles2 = []) {
    const userService = strapi2.service("admin::user");
    if (/[A-Z]/.test(email)) {
      const dbUser = await userService.findOneByEmail(email.toLocaleLowerCase());
      if (dbUser) {
        return dbUser;
      }
    }
    const createdUser = await userService.create({
      firstname: firstname ? firstname : "unset",
      lastname: lastname ? lastname : "",
      email: email.toLocaleLowerCase(),
      roles: roles2,
      preferedLanguage: locale
    });
    return await userService.register({
      registrationToken: createdUser.registrationToken,
      userInfo: {
        firstname: firstname ? firstname : "unset",
        lastname: lastname ? lastname : "user",
        password: generator__default.default.generate({
          length: 43,
          // 256 bits (https://en.wikipedia.org/wiki/Password_strength#Random_passwords)
          numbers: true,
          lowercase: true,
          uppercase: true,
          exclude: '()+_-=}{[]|:;"/?.><,`~',
          strict: true
        })
      }
    });
  },
  addGmailAlias(baseEmail, baseAlias) {
    if (!baseAlias) {
      return baseEmail;
    }
    const alias = baseAlias.replace("/+/g", "");
    const beforePosition = baseEmail.indexOf("@");
    const origin = baseEmail.substring(0, beforePosition);
    const domain = baseEmail.substring(beforePosition);
    return `${origin}+${alias}${domain}`;
  },
  localeFindByHeader(headers) {
    if (headers["accept-language"] && headers["accept-language"].includes("ja")) {
      return "ja";
    } else {
      return "en";
    }
  },
  async triggerWebHook(user) {
    let ENTRY_CREATE;
    const webhookStore = strapi2.serviceMap.get("webhookStore");
    const eventHub = strapi2.serviceMap.get("eventHub");
    if (webhookStore) {
      ENTRY_CREATE = webhookStore.allowedEvents.get("ENTRY_CREATE");
    }
    const modelDef = strapi2.getModel("admin::user");
    const sanitizedEntity = await strapiUtils__default.default.sanitize.sanitizers.defaultSanitizeOutput({
      schema: modelDef,
      getModel: (uid2) => strapi2.getModel(uid2)
    }, user);
    eventHub.emit(ENTRY_CREATE, {
      model: modelDef.modelName,
      entry: sanitizedEntity
    });
  },
  triggerSignInSuccess(user) {
    delete user["password"];
    const eventHub = strapi2.serviceMap.get("eventHub");
    eventHub.emit("admin.auth.success", {
      user,
      provider: "lark-sso"
    });
  },
  // Sign In Success
  renderSignUpSuccess(jwtToken, user, nonce) {
    const config2 = strapi2.config.get("plugin::lark-sso");
    const REMEMBER_ME = config2["REMEMBER_ME"];
    let storage = "sessionStorage";
    if (REMEMBER_ME) {
      storage = "localStorage";
    }
    return `
<!doctype html>
<html>
<head>
<noscript>
<h3>JavaScript must be enabled for authentication</h3>
</noscript>
<script nonce="${nonce}">
 window.addEventListener('load', function() {

  ${storage}.setItem('jwtToken', '"${jwtToken}"');
  ${storage}.setItem('userInfo', '${JSON.stringify(user)}');
   location.href = '${strapi2.config.admin.url}'
 })
<\/script>
</head>
<body>
</body>
</html>`;
  },
  // Sign In Error
  renderSignUpError(message) {
    return `
<!doctype html>
<html>
<head></head>
<body>
<h3>Authentication failed</h3>
<p>${message}</p>
</body>
</html>`;
  }
});
const role = ({ strapi: strapi2 }) => ({
  SSO_TYPE_LARK: "1",
  ssoRoles() {
    return [
      {
        "oauth_type": this.SSO_TYPE_LARK,
        name: "lark"
      }
    ];
  },
  async larkRoles() {
    return await strapi2.query("plugin::lark-sso.roles").findOne({
      where: {
        "oauth_type": this.SSO_TYPE_LARK
      }
    });
  },
  async find() {
    return await strapi2.query("plugin::lark-sso.roles").findMany();
  },
  async update(roles2) {
    const query = strapi2.query("plugin::lark-sso.roles");
    await Promise.all(
      roles2.map((role2) => {
        return query.findOne({ where: { "oauth_type": role2["oauth_type"] } }).then((ssoRole) => {
          if (ssoRole) {
            query.update({
              where: { "oauth_type": role2["oauth_type"] },
              data: { roles: role2.role }
            });
          } else {
            query.create({
              data: {
                "oauth_type": role2["oauth_type"],
                roles: role2.role
              }
            });
          }
        });
      })
    );
  }
});
const services = {
  oauth,
  role
};
const index = {
  register,
  bootstrap,
  destroy,
  config,
  controllers,
  routes,
  services,
  contentTypes,
  policies
};
module.exports = index;
